@@ -21,9 +21,12 @@ use PHPUnit\Framework\Exception;
  */
 class WindowsPhpProcess extends DefaultPhpProcess
 {
-    protected $useTempFile = true;
+    public function getCommand(array $settings, string $file = null): string
+    {
+        return '"' . parent::getCommand($settings, $file) . '"';
+    }
 
-    protected function getHandles()
+    protected function getHandles(): array
     {
         if (false === $stdout_handle = \tmpfile()) {
             throw new Exception(
@@ -32,12 +35,12 @@ class WindowsPhpProcess extends DefaultPhpProcess
         }
 
         return [
-            1 => $stdout_handle
+            1 => $stdout_handle,
         ];
     }
 
-    public function getCommand(array $settings, $file = null)
+    protected function useTemporaryFile(): bool
     {
-        return '"' . parent::getCommand($settings, $file) . '"';
+        return true;
     }
 }
