@@ -11,7 +11,7 @@ use PHPUnit\Framework\TestCase;
 
 class DummyFooTest extends TestCase
 {
-    public function testFooEqualsFoo()
+    public function testFooEqualsFoo(): void
     {
         $this->assertEquals('Foo', 'Foo');
     }
