@@ -1,37 +1,50 @@
 <?php
+/*
+ * This file is part of PHPUnit.
+ *
+ * (c) Sebastian Bergmann <sebastian@phpunit.de>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
 use PHPUnit\Framework\TestCase;
 
 class ExceptionInAssertPreConditionsTest extends TestCase
 {
     public $setUp                = false;
+
     public $assertPreConditions  = false;
+
     public $assertPostConditions = false;
+
     public $tearDown             = false;
+
     public $testSomething        = false;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->setUp = true;
     }
 
-    protected function assertPreConditions()
+    protected function tearDown(): void
     {
-        $this->assertPreConditions = true;
-        throw new Exception;
+        $this->tearDown = true;
     }
 
-    public function testSomething()
+    public function testSomething(): void
     {
         $this->testSomething = true;
     }
 
-    protected function assertPostConditions()
+    protected function assertPreConditions(): void
+    {
+        $this->assertPreConditions = true;
+
+        throw new Exception;
+    }
+
+    protected function assertPostConditions(): void
     {
         $this->assertPostConditions = true;
     }
-
-    protected function tearDown()
-    {
-        $this->tearDown = true;
-    }
 }
